.v-slider.v-input--horizontal .v-input__control[data-v-af51e13c]{min-height:5px}.v-slider.v-input--horizontal[data-v-af51e13c]{margin-inline:unset!important}.volumesliderrow[data-v-a2a4ac06]{margin-top:0;padding-top:0;padding-bottom:0;height:30px;min-height:30px}.heading[data-v-a2a4ac06]{margin-bottom:5px;height:35px}.volumecaption[data-v-a2a4ac06]{width:28px;text-align:right;margin-right:-8px}.expandbtn[data-v-a2a4ac06]{margin-right:-12px}.powerbtn[data-v-a2a4ac06]{right:8px}.volumesliderrow[data-v-a2a4ac06] .v-list-item__prepend{width:40px;margin-left:-25px}.volumesliderrow[data-v-a2a4ac06] .v-list-item__append{width:20px}.checkbox[data-v-a2a4ac06]{margin-right:-5px;width:25px;margin-top:-30px;height:22px!important;min-height:22px!important;display:unset}.syncbtn[data-v-a2a4ac06]{margin-right:-32px;height:25px!important;padding-bottom:20px}.panel-item[data-v-1b70aa95]{border-style:ridge;border-width:thin;border-color:#cccccc5e;padding:5px 8px;background-color:#a2bcff1a;opacity:1;transition:opacity .4s ease-in-out;border-radius:6px;margin:5px 0 8px;height:100%;width:auto}.panel-item-idle[data-v-1b70aa95]{opacity:.8}.panel-item-off[data-v-1b70aa95]{opacity:.6}.panel-item-selected[data-v-1b70aa95]{border-color:#2f2f2f5e;background-color:#a2bcff66}.panel-item-details[data-v-1b70aa95]{align-items:center;margin-left:0!important;padding-left:0!important;padding-right:0!important}.volumesliderrow[data-v-1b70aa95]{margin-top:0;padding-top:0;padding-bottom:0;height:24px;min-height:24px}.volumecaption[data-v-1b70aa95]{width:25px;text-align:right;margin-right:0}.volumesliderrow[data-v-1b70aa95] .v-list-item__prepend{width:40px;margin-left:-25px}.volumesliderrow[data-v-1b70aa95] .v-expansion-panel-text__wrapper{padding:0}.media-thumb[data-v-1b70aa95]{width:55px;height:55px;margin-top:5px;border-radius:4px;background-color:#0000004d}.icon-thumb[data-v-1b70aa95]{width:55px;height:55px;margin-top:5px;border-radius:4px;background-color:#0000004d;display:inline-table}.player-command-btn[data-v-1b70aa95]{width:35px;min-width:35px;margin-left:5px}
